@@ -12,7 +12,7 @@ Test::File::Contents - Test routines for examining the contents of files
 
 =cut
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 use Test::Builder;
 use Digest::MD5;
@@ -439,8 +439,9 @@ sub _slurp {
         :                     ":encoding($encoding)";
     open my $fh, "<$layer", $file or return;
     return '' if eof $fh;
-    local $/;
-    return <$fh>;
+    # Don't use `local $/; return <$fh>;`, it does not work on Windows.
+    # See https://rt.perl.org/Ticket/Display.html?id=127668 for details.
+    return join '', <$fh>;
 }
 
 sub _resolve {
